# cleanupSource

Script for eric to clean up the source tree.

### Global Attributes

None

### Classes

None

### Functions

cleanupSource | Cleanup the sources directory to get rid of leftover files and directories.
main | The main function of the script.

## cleanupSource

cleanupSource(dirName)

Cleanup the sources directory to get rid of leftover files and directories.

dirName
  name of the directory to prune (string)

Up

## main

main(argv)

The main function of the script.

argv
  the list of command line arguments.

Up